#[non_exhaustive]
pub enum BondPrimaryReselect {
    Always,
    Better,
    Failure,
}
The primary_reselect kernel bond option: Specifies the reselection policy for the primary port. This affects how the primary port is chosen to become the active port when failure of the active port or recovery of the primary port occurs. This option is designed to prevent flip-flopping between the primary port and other ports.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Always

The primary port becomes the active port whenever it comes back up. Serialize to always. Deserialize from 0 or always.



Better

The primary port becomes the active port when it comes back up, if the speed and duplex of the primary port is better than the speed and duplex of the current active port. Serialize to better. Deserialize from 1 or better.



Failure

The primary port becomes the active port only if the current active port fails and the primary port is up. Serialize to failure. Deserialize from 2 or failure.