Struct nmstate::EthtoolConfig

source ·
#[non_exhaustive]
pub struct EthtoolConfig { pub pause: Option<EthtoolPauseConfig>, pub feature: Option<EthtoolFeatureConfig>, pub coalesce: Option<EthtoolCoalesceConfig>, pub ring: Option<EthtoolRingConfig>, }
The ethtool configurations. The yaml output of crate::NetworkState containing ethtool information of an ethernet interface would be:

interfaces:
- name: ens3
  type: ethernet
  state: up
  ethtool:
    feature:
      tx-tcp-ecn-segmentation: true
      tx-tcp-mangleid-segmentation: false
      tx-tcp6-segmentation: true
      tx-tcp-segmentation: true
      rx-gro-list: false
      rx-udp-gro-forwarding: false
      rx-gro-hw: true
      tx-checksum-ip-generic: true
      tx-generic-segmentation: true
      rx-gro: true
      tx-nocache-copy: false
    coalesce:
      rx-frames: 1
      tx-frames: 1
    ring:
      rx: 256
      rx-max: 256
      tx: 256
      tx-max: 256

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
pause: Option<EthtoolPauseConfig>

The pause parameters of the specified Ethernet device.

feature: Option<EthtoolFeatureConfig>

The protocol offload and other features of specified network device. Only changeable features are included when querying.

coalesce: Option<EthtoolCoalesceConfig>

The coalescing settings of the specified network device.

ring: Option<EthtoolRingConfig>

The rx/tx ring parameters of the specified network device.

Implementations

source

impl EthtoolConfig

source

pub fn new() -> Self