Struct nmstate::InterfaceIpAddr
source · #[non_exhaustive]pub struct InterfaceIpAddr {
pub ip: IpAddr,
pub prefix_length: u8,
pub mptcp_flags: Option<Vec<MptcpAddressFlag>>,
pub valid_left: Option<String>,
pub preferred_left: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.ip: IpAddrIP address.
prefix_length: u8Prefix length.
Serialize and deserialize to/from prefix-length.
mptcp_flags: Option<Vec<MptcpAddressFlag>>MPTCP flag on this IP address. Ignored when applying as nmstate does not support support IP address specific MPTCP flags. You should apply MPTCP flags at interface level via [BaseInterface.mptcp].
valid_left: Option<String>Remaining time for IP address been valid. The output format is
“32sec” or “forever”.
This property is query only, it will be ignored when applying.
Serialize and deserialize to/from valid-left.
preferred_left: Option<String>Remaining time for IP address been preferred. The output format is
“32sec” or “forever”.
This property is query only, it will be ignored when applying.
Serialize and deserialize to/from preferred-left.