Struct nmstate::Interfaces

source ·
#[non_exhaustive]
pub struct Interfaces { /* private fields */ }
Represent a list of Interface with special serde::Deserializer and serde::Serializer. When applying complex nested interface(e.g. bridge over bond over vlan of eth1), the supported maximum nest level is 4 like previous example. For 5+ nested level, you need to place controller interface before its ports.

Implementations

source

impl Interfaces

source

pub fn new() -> Self

Create empty Interfaces.

source

pub fn is_empty(&self) -> bool

source

pub fn to_vec(&self) -> Vec<&Interface>

Extract internal interfaces to Vec().

source

pub fn get_iface<'a>( &'a self, iface_name: &str, iface_type: InterfaceType ) -> Option<&'a Interface>

Search interface based on interface name and interface type. When using InterfaceType::Unknown, we only search kernel interface(which has presentation in kernel space).

source

pub fn push(&mut self, iface: Interface)

Append specified Interface.

source

pub fn iter(&self) -> impl Iterator<Item = &Interface>

source

pub fn iter_mut(&mut self) -> impl Iterator<Item = &mut Interface>

source

impl Interfaces

source

pub fn update(&mut self, other: &Self)