Struct nmstate::Routes

source ·
#[non_exhaustive]
pub struct Routes { pub running: Option<Vec<RouteEntry>>, pub config: Option<Vec<RouteEntry>>, }
IP routing status

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
running: Option<Vec<RouteEntry>>

Running effected routes containing route from universe or link scope, and only from these protocols:

  • boot (often used by iproute command)
  • static
  • ra
  • dhcp
  • mrouted
  • keepalived
  • babel

Ignored when applying.

config: Option<Vec<RouteEntry>>

Static routes containing route from universe or link scope, and only from these protocols:

  • boot (often used by iproute command)
  • static

When applying, None means preserve current routes. This property is not overriding but adding specified routes to existing routes. To delete a route entry, please [RouteEntry.state] as RouteState::Absent. Any property of absent RouteEntry set to None means wildcard. For example, this crate::NetworkState could remove all routes next hop to interface eth1(showing in yaml):

routes:
  config:
  - next-hop-interface: eth1
    state: absent

To change a route entry, you need to delete old one and add new one(can be in single transaction).

Implementations

source

impl Routes

source

pub fn new() -> Self

source

pub fn is_empty(&self) -> bool

TODO: hide it, internal only

source

pub fn validate(&self) -> Result<(), NmstateError>